@@ -39,6 +39,10 @@
 #' `data[0,0]`. You can override this detection with
 #' `knn.dist.method='precomputed_distance'` or
 #' `knn.dist.method='precomputed_affinity'`.
+#' @param knn.max int, optional, default: NULL
+#' Maximum number of neighbors for which alpha decaying kernel
+#' is computed for each point. For very large datasets, setting `knn.max`
+#' to a small multiple of `knn` can speed up computation significantly.
 #' @param init phate object, optional
 #' object to use for initialization. Avoids recomputing
 #' intermediate steps if parameters are the same.
@@ -117,6 +121,7 @@ phate <- function(data, ndim = 2, knn = 5,
                   n.landmark=2000, gamma=1,
                   t = "auto", mds.solver='sgd',
                   knn.dist.method = "euclidean",
+                  knn.max=NULL,
                   init=NULL,
                   mds.method = "metric", mds.dist.method = "euclidean",
                   t.max=100, npca = 100, plot.optimal.t=FALSE,
@@ -178,6 +183,11 @@ phate <- function(data, ndim = 2, knn = 5,
   } else if (!is.null(npca) && is.na(npca)) {
     npca <- NULL
   }
+  if (is.numeric(knn.max)) {
+    npca <- as.integer(knn.max)
+  } else if (!is.null(knn.max) && is.na(knn.max)) {
+    knn.max <- NULL
+  }
   if (is.numeric(decay)) {
     decay <- as.double(decay)
   } else if (!is.null(decay) && is.na(decay)) {
@@ -201,7 +211,8 @@ phate <- function(data, ndim = 2, knn = 5,
   }
 
   # store parameters
-  params <- list("data" = data, "knn" = knn, "decay" = decay, "t" = t,
+  params <- list("data" = data, "knn" = knn, "knn.max" = knn.max, 
+                 "decay" = decay, "t" = t,
                  "n.landmark" = n.landmark, "gamma" = gamma,
                  "ndim" = ndim, "mds.solver" = mds.solver,
                  "npca" = npca, "mds.method" = mds.method,
@@ -225,6 +236,7 @@ phate <- function(data, ndim = 2, knn = 5,
                           mds = mds.method,
                           mds_dist = mds.dist.method,
                           knn_dist = knn.dist.method,
+                          knn_max = knn.max,
                           n_jobs = n.jobs,
                           random_state = seed,
                           verbose = verbose,
@@ -243,6 +255,7 @@ phate <- function(data, ndim = 2, knn = 5,
                               mds = mds.method,
                               mds_dist = mds.dist.method,
                               knn_dist = knn.dist.method,
+                              knn_max = knn.max,
                               n_jobs = n.jobs,
                               random_state = seed,
                               verbose = verbose,
